==> UndernetCS-v0.2.tar.gz: UndernetCS/UndernetCS-DCC.tcl <==
###############################################################################
#                 Undernet Channel Service Management Script                  #
###############################################################################
# UndernetCS-DCC.tcl                                                          #
###############################################################################
# Copyright (c) 2001 RICHARD Yann alias Ze <Ze@administrateur.net>            #
###############################################################################

###############################################################################
# This program is distributed under the GNU General Public Licence            #
#  See the LICENCE file for more information.                                 #
###############################################################################


# UndernetCS:DCC:ActiveChan 
#   Public DCC command for m|n.
#   Usage: .+cs [#channel] [level]
#   This command active the Undernet Channel Service Script for 'channel'.
#   You can also set a level access to X for the eggdrop.
#   if channel isn't specified, we take the dcc user's console channel.
#   Return: return value must not interpreted to success or failed...
#           because this return is managed for putcmdlog eggdrop system.
####
# Tested: OK (17/03/2001)
bind dcc m|n +cs UndernetCS:DCC:ActiveChan
proc UndernetCS:DCC:ActiveChan {handle idx arguments} {

    set usage "Usage: .+cs \[channel\] \[level\]"
    set chan ""
    set level -1
    if { ([llength $arguments] != 0) && ([llength $arguments] < 3) } {
        foreach arg $arguments {
            if { [validchan $arg] } {
                # We have a channel...
                set chan [string toupper $arg]
                continue
            }
            if { ($arg > 0) && ($arg < 501) } {
                # A level was given.
                set level $arg
            } elseif { $arg == 0 } {
                # Humm level who was given is 0 ...
                # set level to 0 and disable the script
                # for the channel ...
                set level 0
            }
        }
    } elseif { [llength $arguments] == 0 } {
        # There is no arg, so we take the console's user channel.
        set chan [string toupper [lindex [console $idx] 0]]
    } else {
        # Syntax error...
        putdcc $idx "Syntax Error: Bad # of arguments. \n $usage"
        putcmdlog "#$handle# .+cs $arguments (Bad # of args)."
        return 0
    }
    
    if { $chan == "" } {
        set chan [string toupper [lindex [console $idx] 0]]
    }
    
    # Verify access flag ..
    if { ! ( [matchattr $handle n] || [matchattr $handle |m $chan] ) } {
        putdcc $idx "Sorry, you have insufficient access to perform that command."
        putcmdlog "#$handle# .+cs $arg (insufficient access)."
        return 0
    }

    # Analizing arg... and changing some setting ..
    set chlevel 0       ;# to know if level was changed...
    set chstatuschan 0  ;# to know if channel's status was changed...
    
    if { $level != -1 } {
        # A level was given by the user..
        if { [UndernetCS:GetLevel $chan] == $level } {
            # No change for level ...
            if { $level != 0 } {
                if { ![UndernetCS:IsEnabled $chan] } {
                    set chstatuschan 1
                }
            } else {
                # User want to active and change access level to 0 !?
                # Pfffffff :)
                putdcc $idx "Error: You want to active $chan but you change access level for this channel to 0.."
                putdcc $idx "To active UndernetCS management for $chan you MUST have an access level > 0."
                putcmdlog "#$handle# .+CS $arg (Can't active $chan with access level 0)"
                return 0
            }
        } else {
            # Level will be changed ..
            set chlevel 1
        }
    } else {
        # No level was given .. Just want to active this channel
        if { ![UndernetCS:IsEnabled $chan] } {
            if { [UndernetCS:GetLevel $chan] != 0 } {
                # changing status
                set chstatuschan 1
            } else {
                # Error ?! User want to active this channel but level is set to 0..
                putdcc $idx "Error: You want to active $chan but access level for this channel is 0.."
                putdcc $idx "Use .+cs #channel level to active and change level ..."
                putcmdlog "#$handle# .+CS $arg (Can't active $chan with access level 0)"
                return 0
            }
        }
    }
    set needsave 0
    putdcc $idx "Undernet Channel Service:"
    # level
    if { $chlevel } {
        # Change access level for chan.
        UndernetCS:SetNewLevel $chan $level
        putdcc $idx "   Access Level for $chan is now : $level"
        set needsave 1
    }
    # Status
    if { $chstatuschan } {
        # Changing status for this channel
        UndernetCS:SetEnabled $chan
        putdcc $idx "   Status for $chan is now: Enabled"
        if { !$chlevel } {
            putdcc $idx "   Access Level for $chan is : [UndernetCS:GetLevel $chan]"
        }
        set needsave 1
    } elseif { $chlevel } {
        putdcc $idx "   Status for $chan is : [UndernetCS:GetWordChannelStatus $chan]"
    }
    # No change ?
    if { $needsave } {
        UndernetCS:IO:SaveChannelSetting $chan
    } else {
        putdcc $idx "   ---- No change to do ----"
        putdcc $idx "   Status for $chan is : [UndernetCS:GetWordChannelStatus $chan]"
        putdcc $idx "   Access Level for $chan is : [UndernetCS:GetLevel $chan]"
    }
    return 1
}

####
# Tested: OK (17/03/2001)
bind dcc m|n -cs UndernetCS:DCC:UnactiveChan
proc UndernetCS:DCC:UnactiveChan {handle idx arg} {
   
    set usage "Usage: .-cs \[#channel\]"
    if { [llength $arg] == 0 } {
        set chan [string toupper [lindex [console $idx] 0]]
    } elseif { [llength $arg] == 1 } {
        set chan [string toupper $arg]
        # Verify if it's a valid channel
        if { ![validchan $chan] } {
            putdcc $idx "$chan isn't a valid channel."
            putdcc $idx "$usage"
            putcmdlog "#$handle# .+cs $arg (Bad # of arg)."
        }
    } else {
        putdcc $idx "$usage"
        putcmdlog "#$handle# .+cs $arg (Bad # of arg)."
        return 0
    }
    # Verify access flag ..
    if { ! ( [matchattr $handle n] || [matchattr $handle |m $chan] ) } {
        putdcc $idx "Sorry, you have insufficient access to perform that command."
        putcmdlog "#$handle# .+cs $arg (insufficient access)."
        return 0
    }
    
    if { ![UndernetCS:IsEnabled $chan] } {
        putdcc $idx "Status of $chan is already disabled."
        return 1
    }
    # Now unactive this chan if level is more than 0 ...
    UndernetCS:SetDisabled "$chan"
    UndernetCS:IO:SaveChannelSetting $chan
    putdcc $idx "Undernet Channel Service:"
    putdcc $idx "    Status for $chan is now: Disabled."
    return 1
}

####
# Tested: OK (17/03/2001)
bind dcc n| cs UndernetCS:DCC:CS
proc UndernetCS:DCC:CS {handle idx arg} {

    set usage "\n .cs set \[user <username>\] \[pass <password>\]"
    set usage "$usage \[check_auth <min>\] \[status <ON|OFF>\]\n"
    set usage "$usage .cs chanset \[#chan\] \[status <ON|OFF>\] \[automode <OP|VOICE|NONE>\]"
    set usage "$usage \[level <access level>\] \[check_susp <min>\]"

    if { [llength $arg] == 0 } {
        putdcc $idx "Usage: $usage"
        putcmdlog "#$handle# .cs $arg (Bad # of arg)."
        return 0
    }

    set cmd "[string tolower [lindex $arg 0]]"
    if { $cmd == "set" } {
        # Verify access flag ..
        if { ![matchattr $handle n] } {
            putdcc $idx "Sorry, you have insufficient access to perform that command."
            putcmdlog "#$handle# .cs $arg (insufficient access)."
            return 0
        }
        set res [UndernetCS:DCC:CS_Set $handle $idx "[lrange $arg 1 end]"]
        return $res
    }

    if { $cmd == "chanset" } {
        set argline [string tolower [lrange $arg 1 end]]
        set res [UndernetCS:DCC:CS_ChanSet $handle $idx $argline]
        return $res
    }
    if { $cmd == "list" } {
        putdcc $idx "Undernet Channel Service:"
        putdcc $idx "    Global setting:"
        putdcc $idx "        Username: [UndernetCS:GetUserId]"
        putdcc $idx "        Password: [UndernetCS:GetPass]"
        putdcc $idx "        Status: [UndernetCS:GetWordScriptStatus]"
        putdcc $idx "        Check Auth Frequency: Each [UndernetCS:GetAuthCheckFrequency] minutes"
        foreach channel [channels] {
            set chan [string toupper $channel]
            putdcc $idx "    $channel setting:"
            putdcc $idx "        Status : [UndernetCS:GetWordChannelStatus $chan]"
            putdcc $idx "        Level : [UndernetCS:GetLevel $chan]"
            putdcc $idx "        AutoMode : [UndernetCS:GetAutoMode $chan]"
            putdcc $idx "        Suspended : [UndernetCS:IsSuspended $chan]"
            putdcc $idx "        Check Auth when access suspended: Each [UndernetCS:GetSuspendedAuthCheckFrequency $chan] minutes"
        }
        return 1
    }
    putdcc $idx "$usage"
    putdcc $idx "Command must be set, chanset or list..."
    putcmdlog "#$handle# .cs $arg (bad first arg)."
    return 0
}

####
# Tested: OK (17/03/2001)
proc UndernetCS:DCC:CS_Set {handle idx arg} {

    set res "Channel Service:\n"
    set userset 0
    set passset 0
    set authchk 0
    set status 0

    if { [llength $arg] == 0 } {
        putdcc $idx "Undernet Channel Service:"
        putdcc $idx "    Status: [UndernetCS:GetWordScriptStatus]"
        putdcc $idx "    Bot's Username: [UndernetCS:GetUserId]"
        putdcc $idx "    Bot's Password: [UndernetCS:GetPass]"
        putdcc $idx "    Authentication is checked each [UndernetCS:GetAuthCheckFrequency] minutes."
        return 1
    }
    set i 0
    foreach {cmd val} $arg {
        set cmd [string tolower $cmd]
        if { ($cmd == "user") && ($userset == 0) } {
            set userset $val
        } elseif { ($cmd == "pass") && ($passset == 0) } {
            incr i 1
            set passset [lrange $arg $i end]
            break
        } elseif { ($cmd == "check_auth") && ($authchk == 0) } {
            set authchk $val
        } elseif { ($cmd == "status") && ($status == 0) } {
            set status [string toupper $val]
        } elseif {
            # Hummm
            set usage ".cs set \[user <username>\] \[check_auth <min>\]"
            set usage "$usage \[status <ON|OFF>\] \[pass <password>\]"
            putdcc $idx "$usage"
            putdcc $idx "'pass' MUST be the last element when you set several option."
            putcmdlog "#$handle# .cs $arg (!!Bad # of arg!!)."
            return 0
        }
        incr i 2
    }
    set displayarg ""
    set needsave 0
    if { $userset != 0 } {
        if { [string tolower [UndernetCS:GetUserId]] == [string tolower $userset] } {
            set res "$res    No change to do for eggdrop's username.\n"
        } else {
            UndernetCS:SetUserId $userset
            set res "$res    Internal value of X's Username changed to \"$userset\".\n"
            set needsave 1
        }
        set displayarg "user [UndernetCS:GetUserId]"
    }
    if { $passset != 0 } {
        if { $passset == [UndernetCS:GetPass] } {
            set res "$res    No change to do for X eggdrop's password.\n"
        } else {
            UndernetCS:SetPass "$passset"
            set res "$res    Internal value of X's Password changed.\n"
            set needsave 1
        }
        set displayarg "$displayarg pass (Something...)"
        if { [UndernetCS:IsAuthFailed] } {
            # Retry now to login to X.
            UndernetCS:SetAuthStatus 0
            UndernetCS:Auth:Login2X
        }
    }
    if { $authchk  != 0 } {
        if { $authchk  == [UndernetCS:GetAuthCheckFrequency] } {
            set res "$res    No change to do for Authentication check frequency.\n"
        } else {
            UndernetCS:SetAuthCheckFrequency $authchk
            set res "$res    Authentication is now check each $authchk minutes.\n"
            set needsave 1
        }
        set displayarg "$displayarg auth_check $authchk"
    }
    if { $status != 0 } {
        if { [UndernetCS:IsActived] == 1 } {
            set current "ON"
            set changeto 0 
        } else {
            set current "OFF"
            set changeto 1
        }
        if { $status == $current } {
            set res "$res    No change to do for status of the script.\n"
        } else {
            UndernetCS:SetGlobalStatus $changeto
            set res "$res    The script is now [UndernetCS:GetWordScriptStatus].\n"
            set needsave 1
        }
        set displayarg "$displayarg status $status"
    }
    putdcc $idx "$res"
    if { $needsave == 1 } {
        UndernetCS:IO:SaveGlobalSetting
    }
    putcmdlog "#$handle# .cs $displayarg."
    return 0
}

####
# Tested: OK (17/03/2001)
proc UndernetCS:DCC:CS_ChanSet {handle idx arg} {

    set usage ".cs chanset \[#chan\] \[status <ON|OFF>\] \[automode <OP|VOICE|NONE>\]"
    set usage "$usage \[level <access level>\] \[check_susp <min>\]"
    set chan ""
    
    if { [llength $arg] == 0 } {
        set chan [lindex [console $idx] 0]
    } elseif { [validchan [lindex $arg 0]] } {
    	set chan [lindex $arg 0]
    	set arg [lrange $arg 1 end]
    } else {
    	set chan [lindex [console $idx] 0]
    }

    # Verify access flag for this user/channel.
    if { ! ( ( [matchattr $handle n] == 1 ) || ( [mattchttr $handle |n $chan] == 1 ) ) } {
            putdcc $idx "Sorry, you have insufficient access to perform that command."
            putcmdlog "#$handle# .cs $arg (insufficient access)."
            return 0
    }

    if { [llength $arg] == 0 } {
        putdcc $idx "    $chan setting:"
        putdcc $idx "        Status : [UndernetCS:GetWordChannelStatus $chan]"
        putdcc $idx "        Level : [UndernetCS:GetLevel $chan]"
        putdcc $idx "        AutoMode : [UndernetCS:GetAutoMode $chan]"
        putdcc $idx "        Suspended : [UndernetCS:IsSuspended $chan]"
        putdcc $idx "        Check Auth when access suspended: Each [UndernetCS:GetSuspendedAuthCheckFrequency $chan] minutes"
        return 1
    }

    # Access si Ok..
    set status ""
    set automode ""
    set check_auth ""
    set check_susp ""
    set level ""
    set ALL_IS_OK 1
    foreach {cmd val} $arg {
    	# check for status key word.
    	if { $cmd == "status" } {
    	    if { $val == "on" } {
    	    	set status 1
    	    } elseif { $val == "off" } {
        		set status 0
    	    } else {
        		set ALL_IS_OK 0
        		break
    	    }
    	    continue
    	}
    	# Check for automode key word
    	if { $cmd == "automode" } {
    	    if { $val == "op" || $val == "voice" || $val == "none" } {
    		    set automode $val
    		    continue
    	    } else {
    		    set ALL_IS_OK 0
    		    break
    	    }
    	}
    	if { $cmd == "check_susp" } {
    	    set check_susp $val
    	    continue
    	}
    	if { $cmd == "level" } {
    	    if { $val > 0 && $val <=500 } {
    	        set level $val
    	    } else {
    	        set ALL_IS_OK 0
    	    }
    	}
    }
    # end of foreach ...
    if { $ALL_IS_OK == 0 } {
    	putdcc $idx "Syntax error.. $cmd $val isn't valid."
    	putcmdlog "#$handle# .cs $arg (Bad arg)."
    	return 0
    }
    set needsave 0
    putdcc $idx "Channel Service:\n"
    # Status report and change.
    if { $status != "" } {
        if { [UndernetCS:IsEnabled $chan] == $status } {
            putdcc $idx "\t Status for $chan is ALREADY : $status"
        } else {
            set needsave 1
            if { $status == 1 } {
            	UndernetCS:SetEnabled "$chan"
            	putdcc $idx "\t Status for $chan is now: Enabled."
            } else {
            	UndernetCS:SetDisabled "$chan"
            	putdcc $idx "\t Status for $chan is now: Disabled."
            }
        }
    }
    # Automode report and change
    if { $automode != "" } {
        set automode [string toupper $automode]
    	if { [UndernetCS:GetAutoMode $chan] != $automode } {
        	UndernetCS:SetAutoMode "$chan" "$automode"
        	putdcc $idx "\t AUTOMODE for $chan is now: $automode"
        	set needsave 1
        } else {
            putdcc $idx "\t AUTOMODE for $chan is ALREADY : $automode"
        }
    }
    # Check when suspended
    if { $check_susp != "" } {
    	if { [UndernetCS:GetSuspendedAuthCheckFrequency $chan] != $check_susp } {
        	UndernetCS:SetSuspendedAuthCheckFrequency "$chan" "$check_susp"
        	putdcc $idx "\t Authentication when access is suspended on $chan is now checked any $check_susp minutes."
        	set needsave 1
        } else {
            putdcc $idx "\t Authentication when access is suspended on $chan is ALREADY checked any $check_susp minutes."
        }
    }
    # Check for chaning level
    if { $level != "" } {
        if { [UndernetCS:GetLevel $chan] != $level } {
            putdcc $idx "\t Access Level for $chan is now $level."
            set needsave 1
        } else {
            putdcc $idx "\t Access Level for $chan is ALREADY set to $level."
        }
    }
    if { $needsave } {
        UndernetCS:IO:SaveChannelSetting $chan
    }
    return 1
}
### EOF ###

==> UndernetCS-v0.3.tar.gz: UndernetCS/UndernetCS-DCC.tcl <==
###############################################################################
#                 Undernet Channel Service Management Script                  #
###############################################################################
# UndernetCS-DCC.tcl                                                          #
###############################################################################
# Copyright (c) 2001 RICHARD Yann alias Ze <Ze@administrateur.net>            #
###############################################################################

###############################################################################
# This program is distributed under the GNU General Public Licence            #
#  See the LICENCE file for more information.                                 #
###############################################################################

####
# Tested: OK (17/03/2001)
bind dcc m|n -cs UndernetCS:DCC:UnactiveChan
proc UndernetCS:DCC:UnactiveChan {handle idx arg} {
   
    set usage "Usage: .-cs \[#channel\]"
    if { [llength $arg] == 0 } {
        set chan [string toupper [lindex [console $idx] 0]]
    } elseif { [llength $arg] == 1 } {
        set chan [string toupper $arg]
        # Verify if it's a valid channel
        if { ![validchan $chan] } {
            putdcc $idx "$chan isn't a valid channel."
            putdcc $idx "$usage"
            putcmdlog "#$handle# .+cs $arg (Bad # of arg)."
        }
    } else {
        putdcc $idx "$usage"
        putcmdlog "#$handle# .+cs $arg (Bad # of arg)."
        return 0
    }
    # Verify access flag ..
    if { ! ( [matchattr $handle n] || [matchattr $handle |m $chan] ) } {
        putdcc $idx "Sorry, you have insufficient access to perform that command."
        putcmdlog "#$handle# .+cs $arg (insufficient access)."
        return 0
    }
    
    if { ![UndernetCS:IsEnabled $chan] } {
        putdcc $idx "Status of $chan is already disabled."
        return 1
    }
    # Now unactive this chan if level is more than 0 ...
    UndernetCS:SetDisabled "$chan"
    UndernetCS:IO:SaveChannelSetting $chan
    putdcc $idx "Undernet Channel Service:"
    putdcc $idx "    Status for $chan is now: Disabled."
    return 1
}

####
# Tested: OK (17/03/2001)
bind dcc n| cs UndernetCS:DCC:CS
proc UndernetCS:DCC:CS {handle idx arg} {

    set usage "\n .cs set \[user <username>\] \[pass <password>\]"
    set usage "$usage \[check_auth <min>\] \[status <ON|OFF>\]\n"
    set usage "$usage .cs chanset \[#chan\] \[status <ON|OFF>\] \[automode <OP|VOICE|NONE>\]"
    set usage "$usage \[level <access level>\] \[check_susp <min>\]"

    if { [llength $arg] == 0 } {
        putdcc $idx "Usage: $usage"
        putcmdlog "#$handle# .cs $arg (Bad # of arg)."
        return 0
    }

    set cmd "[string tolower [lindex $arg 0]]"
    if { $cmd == "set" } {
        # Verify access flag ..
        if { ![matchattr $handle n] } {
            putdcc $idx "Sorry, you have insufficient access to perform that command."
            putcmdlog "#$handle# .cs $arg (insufficient access)."
            return 0
        }
        set res [UndernetCS:DCC:CS_Set $handle $idx "[lrange $arg 1 end]"]
        return $res
    }

    if { $cmd == "chanset" } {
        set argline [string tolower [lrange $arg 1 end]]
        set res [UndernetCS:DCC:CS_ChanSet $handle $idx $argline]
        return $res
    }
    if { $cmd == "list" } {
        putdcc $idx "Undernet Channel Service:"
        putdcc $idx "    Global setting:"
        putdcc $idx "        Username: [UndernetCS:GetUserId]"
        putdcc $idx "        Password: [UndernetCS:GetPass]"
        putdcc $idx "        Status: [UndernetCS:GetWordScriptStatus]"
        putdcc $idx "        Check Auth Frequency: Each [UndernetCS:GetAuthCheckFrequency] minutes"
        foreach channel [channels] {
            set chan [string toupper $channel]
            putdcc $idx "    $channel setting:"
            putdcc $idx "        Status : [UndernetCS:GetWordChannelStatus $chan]"
            putdcc $idx "        Level : [UndernetCS:GetLevel $chan]"
            putdcc $idx "        AutoMode : [UndernetCS:GetAutoMode $chan]"
            putdcc $idx "        Suspended : [UndernetCS:IsSuspended $chan]"
            putdcc $idx "        Check Auth when access suspended: Each [UndernetCS:GetSuspendedAuthCheckFrequency $chan] minutes"
        }
        return 1
    }
    putdcc $idx "$usage"
    putdcc $idx "Command must be set, chanset or list..."
    putcmdlog "#$handle# .cs $arg (bad first arg)."
    return 0
}

####
# Tested: OK (17/03/2001)
proc UndernetCS:DCC:CS_Set {handle idx arg} {

    set res "Channel Service:\n"
    set userset 0
    set passset 0
    set authchk 0
    set status 0

    if { [llength $arg] == 0 } {
        putdcc $idx "Undernet Channel Service:"
        putdcc $idx "    Status: [UndernetCS:GetWordScriptStatus]"
        putdcc $idx "    Bot's Username: [UndernetCS:GetUserId]"
        putdcc $idx "    Bot's Password: [UndernetCS:GetPass]"
        putdcc $idx "    Authentication is checked each [UndernetCS:GetAuthCheckFrequency] minutes."
        return 1
    }
    set i 0
    foreach {cmd val} $arg {
        set cmd [string tolower $cmd]
        if { ($cmd == "user") && ($userset == 0) } {
            set userset $val
        } elseif { ($cmd == "pass") && ($passset == 0) } {
            incr i 1
            set passset [lrange $arg $i end]
            break
        } elseif { ($cmd == "check_auth") && ($authchk == 0) } {
            set authchk $val
        } elseif { ($cmd == "status") && ($status == 0) } {
            set status [string toupper $val]
        } else {
            # Hummm
            set usage ".cs set \[user <username>\] \[check_auth <min>\]"
            set usage "$usage \[status <ON|OFF>\] \[pass <password>\]"
            putdcc $idx "$usage"
            putdcc $idx "'pass' MUST be the last element when you set several option."
            putcmdlog "#$handle# .cs $arg (!!Bad # of arg!!)."
            return 0
        }
        incr i 2
    }
    set displayarg ""
    set needsave 0
    if { $userset != 0 } {
        if { [string tolower [UndernetCS:GetUserId]] == [string tolower $userset] } {
            set res "$res    No change to do for eggdrop's username.\n"
        } else {
            UndernetCS:SetUserId $userset
            set res "$res    Internal value of X's Username changed to \"$userset\".\n"
            set needsave 1
        }
        set displayarg "user [UndernetCS:GetUserId]"
    }
    if { $passset != 0 } {
        if { $passset == [UndernetCS:GetPass] } {
            set res "$res    No change to do for X eggdrop's password.\n"
        } else {
            UndernetCS:SetPass "$passset"
            set res "$res    Internal value of X's Password changed.\n"
            set needsave 1
        }
        set displayarg "$displayarg pass (Something...)"
        if { [UndernetCS:IsAuthFailed] } {
            # Retry now to login to X.
            UndernetCS:SetAuthStatus 0
            UndernetCS:Auth:Login2X
        }
    }
    if { $authchk  != 0 } {
        if { $authchk  == [UndernetCS:GetAuthCheckFrequency] } {
            set res "$res    No change to do for Authentication check frequency.\n"
        } else {
            UndernetCS:SetAuthCheckFrequency $authchk
            set res "$res    Authentication is now check each $authchk minutes.\n"
            set needsave 1
        }
        set displayarg "$displayarg auth_check $authchk"
    }
    if { $status != 0 } {
        if { [UndernetCS:IsActived] == 1 } {
            set current "ON"
            set changeto 0 
        } else {
            set current "OFF"
            set changeto 1
        }
        if { $status == $current } {
            set res "$res    No change to do for status of the script.\n"
        } else {
            UndernetCS:SetGlobalStatus $changeto
            set res "$res    The script is now [UndernetCS:GetWordScriptStatus].\n"
            set needsave 1
        }
        set displayarg "$displayarg status $status"
    }
    putdcc $idx "$res"
    if { $needsave == 1 } {
        UndernetCS:IO:SaveGlobalSetting
    }
    putcmdlog "#$handle# .cs $displayarg."
    return 0
}

####
# Tested: OK (17/03/2001)
proc UndernetCS:DCC:CS_ChanSet {handle idx arg} {

    set usage ".cs chanset \[#chan\] \[status <ON|OFF>\] \[automode <OP|VOICE|NONE>\]"
    set usage "$usage \[level <access level>\] \[check_susp <min>\]"
    set chan ""
    
    if { [llength $arg] == 0 } {
        set chan [lindex [console $idx] 0]
    } elseif { [validchan [lindex $arg 0]] } {
    	set chan [lindex $arg 0]
    	set arg [lrange $arg 1 end]
    } else {
    	set chan [lindex [console $idx] 0]
    }

    # Verify access flag for this user/channel.
    if { ! ( ( [matchattr $handle n] == 1 ) || ( [mattchttr $handle |n $chan] == 1 ) ) } {
            putdcc $idx "Sorry, you have insufficient access to perform that command."
            putcmdlog "#$handle# .cs $arg (insufficient access)."
            return 0
    }

    if { [llength $arg] == 0 } {
        putdcc $idx "    $chan setting:"
        putdcc $idx "        Status : [UndernetCS:GetWordChannelStatus $chan]"
        putdcc $idx "        Level : [UndernetCS:GetLevel $chan]"
        putdcc $idx "        AutoMode : [UndernetCS:GetAutoMode $chan]"
        putdcc $idx "        Suspended : [UndernetCS:IsSuspended $chan]"
        putdcc $idx "        Check Auth when access suspended: Each [UndernetCS:GetSuspendedAuthCheckFrequency $chan] minutes"
        return 1
    }

    # Access si Ok..
    set status ""
    set automode ""
    set check_auth ""
    set check_susp ""
    set level ""
    set ALL_IS_OK 1
    foreach {cmd val} $arg {
    	# check for status key word.
    	if { $cmd == "status" } {
    	    if { $val == "on" } {
    	    	set status 1
    	    } elseif { $val == "off" } {
        		set status 0
    	    } else {
        		set ALL_IS_OK 0
        		break
    	    }
    	    continue
    	}
    	# Check for automode key word
    	if { $cmd == "automode" } {
    	    if { $val == "op" || $val == "voice" || $val == "none" } {
    		    set automode $val
    		    continue
    	    } else {
    		    set ALL_IS_OK 0
    		    break
    	    }
    	}
    	if { $cmd == "check_susp" } {
    	    set check_susp $val
    	    continue
    	}
    	if { $cmd == "level" } {
    	    if { $val > 0 && $val <=500 } {
    	        set level $val
    	    } else {
    	        set ALL_IS_OK 0
    	    }
    	}
    }
    # end of foreach ...
    if { $ALL_IS_OK == 0 } {
    	putdcc $idx "Syntax error.. $cmd $val isn't valid."
    	putcmdlog "#$handle# .cs $arg (Bad arg)."
    	return 0
    }
    set needsave 0
    putdcc $idx "Channel Service:\n"
    # Check for changing level
    if { $level != "" } {
        if { [UndernetCS:GetLevel $chan] != $level } {
            putdcc $idx "\t Access Level for $chan is now $level."
	    UndernetCS:SetNewLevel "$chan" "$level"
            set needsave 1
        } else {
            putdcc $idx "\t Access Level for $chan is ALREADY set to $level."
        }
    }
    # Status report and change.
    if { $status != "" } {
        if { [UndernetCS:IsEnabled $chan] == $status } {
            putdcc $idx "\t Status for $chan is ALREADY : $status"
        } else {
            set needsave 1
            if { $status == 1 } {
            	UndernetCS:SetEnabled "$chan"
            	putdcc $idx "\t Status for $chan is now: Enabled."
            } else {
            	UndernetCS:SetDisabled "$chan"
            	putdcc $idx "\t Status for $chan is now: Disabled."
            }
        }
    }
    # Automode report and change
    if { $automode != "" } {
        set automode [string toupper $automode]
    	if { [UndernetCS:GetAutoMode $chan] != $automode } {
        	UndernetCS:SetAutoMode "$chan" "$automode"
        	putdcc $idx "\t AUTOMODE for $chan is now: $automode"
        	set needsave 1
        } else {
            putdcc $idx "\t AUTOMODE for $chan is ALREADY : $automode"
        }
    }
    # Check when suspended
    if { $check_susp != "" } {
    	if { [UndernetCS:GetSuspendedAuthCheckFrequency $chan] != $check_susp } {
        	UndernetCS:SetSuspendedAuthCheckFrequency "$chan" "$check_susp"
        	putdcc $idx "\t Authentication when access is suspended on $chan is now checked any $check_susp minutes."
        	set needsave 1
        } else {
            putdcc $idx "\t Authentication when access is suspended on $chan is ALREADY checked any $check_susp minutes."
        }
    }
    if { $needsave == 1 } {
	UndernetCS:IO:SaveChannelSetting "$chan"
    }
    return 1
}
### EOF ###
